{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "DNase-seq 01 mapping - reads: SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#01-map-se.cwl/ENCODE_blacklist_bedfile"
                },
                {
                    "doc": "Bowtie first index files for reference genome (e.g. *1.ebwt). The rest of the files should be in the same folder.",
                    "type": "File",
                    "id": "#01-map-se.cwl/genome_ref_first_index_file"
                },
                {
                    "doc": "Genome sizes tab-delimited file (used in samtools)",
                    "type": "File",
                    "id": "#01-map-se.cwl/genome_sizes_file"
                },
                {
                    "doc": "Input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#01-map-se.cwl/input_fastq_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#01-map-se.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#bowtie-se.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/genome_ref_first_index_file",
                            "id": "#01-map-se.cwl/bowtie-se/genome_ref_first_index_file"
                        },
                        {
                            "source": "#01-map-se.cwl/input_fastq_files",
                            "id": "#01-map-se.cwl/bowtie-se/input_fastq_file"
                        },
                        {
                            "source": "#01-map-se.cwl/nthreads",
                            "id": "#01-map-se.cwl/bowtie-se/nthreads"
                        },
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/bowtie-se/output_filename"
                        },
                        {
                            "valueFrom": "${return 20}",
                            "id": "#01-map-se.cwl/bowtie-se/seedlen"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#01-map-se.cwl/bowtie-se/seedmms"
                        },
                        {
                            "valueFrom": "${return 30}",
                            "id": "#01-map-se.cwl/bowtie-se/trim3"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-map-se.cwl/bowtie-se/input_fastq_file",
                        "#01-map-se.cwl/bowtie-se/output_filename"
                    ],
                    "out": [
                        "#01-map-se.cwl/bowtie-se/output_aligned_file",
                        "#01-map-se.cwl/bowtie-se/output_bowtie_log"
                    ],
                    "id": "#01-map-se.cwl/bowtie-se"
                },
                {
                    "run": "#count-fastq-reads.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/count_fastq_reads/input_basename"
                        },
                        {
                            "source": "#01-map-se.cwl/input_fastq_files",
                            "id": "#01-map-se.cwl/count_fastq_reads/input_fastq_file"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-map-se.cwl/count_fastq_reads/input_fastq_file",
                        "#01-map-se.cwl/count_fastq_reads/input_basename"
                    ],
                    "out": [
                        "#01-map-se.cwl/count_fastq_reads/output_read_count"
                    ],
                    "id": "#01-map-se.cwl/count_fastq_reads"
                },
                {
                    "in": [
                        {
                            "source": "#01-map-se.cwl/genome_sizes_file",
                            "id": "#01-map-se.cwl/execute_pcr_bottleneck_coef/genome_sizes"
                        },
                        {
                            "source": "#01-map-se.cwl/filtered2sorted/sorted_file",
                            "id": "#01-map-se.cwl/execute_pcr_bottleneck_coef/input_bam_files"
                        },
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/execute_pcr_bottleneck_coef/input_output_filenames"
                        }
                    ],
                    "run": "#pcr-bottleneck-coef.cwl",
                    "out": [
                        "#01-map-se.cwl/execute_pcr_bottleneck_coef/pbc_file"
                    ],
                    "id": "#01-map-se.cwl/execute_pcr_bottleneck_coef"
                },
                {
                    "run": "#extract-basename.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/input_fastq_files",
                            "id": "#01-map-se.cwl/extract_basename/input_file"
                        }
                    ],
                    "scatter": "#01-map-se.cwl/extract_basename/input_file",
                    "out": [
                        "#01-map-se.cwl/extract_basename/output_basename"
                    ],
                    "id": "#01-map-se.cwl/extract_basename"
                },
                {
                    "run": "#samtools-filter-unmapped.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/sort_bams/sorted_file",
                            "id": "#01-map-se.cwl/filter-unmapped/input_file"
                        },
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/filter-unmapped/output_filename"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-map-se.cwl/filter-unmapped/input_file",
                        "#01-map-se.cwl/filter-unmapped/output_filename"
                    ],
                    "out": [
                        "#01-map-se.cwl/filter-unmapped/filtered_file"
                    ],
                    "id": "#01-map-se.cwl/filter-unmapped"
                },
                {
                    "in": [
                        {
                            "source": "#01-map-se.cwl/remove_encode_blacklist/file_wo_blacklist_regions",
                            "id": "#01-map-se.cwl/filter_pcr_artifacts/input_bam_files"
                        }
                    ],
                    "run": "#filter-pcr-artifacts.cwl",
                    "out": [
                        "#01-map-se.cwl/filter_pcr_artifacts/filtered_bedfile"
                    ],
                    "id": "#01-map-se.cwl/filter_pcr_artifacts"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/filter-unmapped/filtered_file",
                            "id": "#01-map-se.cwl/filtered2sorted/input_file"
                        },
                        {
                            "source": "#01-map-se.cwl/nthreads",
                            "id": "#01-map-se.cwl/filtered2sorted/nthreads"
                        }
                    ],
                    "scatter": [
                        "#01-map-se.cwl/filtered2sorted/input_file"
                    ],
                    "out": [
                        "#01-map-se.cwl/filtered2sorted/sorted_file"
                    ],
                    "id": "#01-map-se.cwl/filtered2sorted"
                },
                {
                    "run": "#bedtools-bedtobam.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/genome_sizes_file",
                            "id": "#01-map-se.cwl/filtered_bed_to_bam/g"
                        },
                        {
                            "source": "#01-map-se.cwl/filter_pcr_artifacts/filtered_bedfile",
                            "id": "#01-map-se.cwl/filtered_bed_to_bam/i"
                        }
                    ],
                    "scatter": [
                        "#01-map-se.cwl/filtered_bed_to_bam/i"
                    ],
                    "out": [
                        "#01-map-se.cwl/filtered_bed_to_bam/bam_file"
                    ],
                    "id": "#01-map-se.cwl/filtered_bed_to_bam"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/sort_filtered_bam/sorted_file",
                            "id": "#01-map-se.cwl/index_filtered_bam/input_file"
                        }
                    ],
                    "scatter": [
                        "#01-map-se.cwl/index_filtered_bam/input_file"
                    ],
                    "out": [
                        "#01-map-se.cwl/index_filtered_bam/indexed_file"
                    ],
                    "id": "#01-map-se.cwl/index_filtered_bam"
                },
                {
                    "run": "#samtools-extract-number-mapped-reads.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/sort_filtered_bam/sorted_file",
                            "id": "#01-map-se.cwl/mapped_filtered_reads_count/input_bam_file"
                        },
                        {
                            "valueFrom": ".mapped_and_filtered.read_count.txt",
                            "id": "#01-map-se.cwl/mapped_filtered_reads_count/output_suffix"
                        }
                    ],
                    "scatter": "#01-map-se.cwl/mapped_filtered_reads_count/input_bam_file",
                    "out": [
                        "#01-map-se.cwl/mapped_filtered_reads_count/output_read_count"
                    ],
                    "id": "#01-map-se.cwl/mapped_filtered_reads_count"
                },
                {
                    "run": "#bowtie-log-read-count.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/bowtie-se/output_bowtie_log",
                            "id": "#01-map-se.cwl/mapped_reads_count/bowtie_log"
                        }
                    ],
                    "scatter": "#01-map-se.cwl/mapped_reads_count/bowtie_log",
                    "out": [
                        "#01-map-se.cwl/mapped_reads_count/output"
                    ],
                    "id": "#01-map-se.cwl/mapped_reads_count"
                },
                {
                    "run": "#preseq-percent-uniq-reads.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/preseq-c-curve/output_file",
                            "id": "#01-map-se.cwl/percent_uniq_reads/preseq_c_curve_outfile"
                        }
                    ],
                    "scatter": "#01-map-se.cwl/percent_uniq_reads/preseq_c_curve_outfile",
                    "out": [
                        "#01-map-se.cwl/percent_uniq_reads/output"
                    ],
                    "id": "#01-map-se.cwl/percent_uniq_reads"
                },
                {
                    "run": "#preseq-c_curve.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/sort_bams/sorted_file",
                            "id": "#01-map-se.cwl/preseq-c-curve/input_sorted_file"
                        },
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/preseq-c-curve/output_file_basename"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-map-se.cwl/preseq-c-curve/input_sorted_file",
                        "#01-map-se.cwl/preseq-c-curve/output_file_basename"
                    ],
                    "out": [
                        "#01-map-se.cwl/preseq-c-curve/output_file"
                    ],
                    "id": "#01-map-se.cwl/preseq-c-curve"
                },
                {
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/filtered2sorted/sorted_file",
                            "id": "#01-map-se.cwl/remove_encode_blacklist/a"
                        },
                        {
                            "source": "#01-map-se.cwl/ENCODE_blacklist_bedfile",
                            "id": "#01-map-se.cwl/remove_encode_blacklist/b"
                        },
                        {
                            "source": "#01-map-se.cwl/extract_basename/output_basename",
                            "id": "#01-map-se.cwl/remove_encode_blacklist/output_basename_file"
                        },
                        {
                            "default": true,
                            "id": "#01-map-se.cwl/remove_encode_blacklist/v"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-map-se.cwl/remove_encode_blacklist/a",
                        "#01-map-se.cwl/remove_encode_blacklist/output_basename_file"
                    ],
                    "out": [
                        "#01-map-se.cwl/remove_encode_blacklist/file_wo_blacklist_regions"
                    ],
                    "id": "#01-map-se.cwl/remove_encode_blacklist"
                },
                {
                    "run": "#samtools2bam.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/bowtie-se/output_aligned_file",
                            "id": "#01-map-se.cwl/sam2bam/input_file"
                        }
                    ],
                    "scatter": [
                        "#01-map-se.cwl/sam2bam/input_file"
                    ],
                    "out": [
                        "#01-map-se.cwl/sam2bam/bam_file"
                    ],
                    "id": "#01-map-se.cwl/sam2bam"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/sam2bam/bam_file",
                            "id": "#01-map-se.cwl/sort_bams/input_file"
                        },
                        {
                            "source": "#01-map-se.cwl/nthreads",
                            "id": "#01-map-se.cwl/sort_bams/nthreads"
                        }
                    ],
                    "scatter": [
                        "#01-map-se.cwl/sort_bams/input_file"
                    ],
                    "out": [
                        "#01-map-se.cwl/sort_bams/sorted_file"
                    ],
                    "id": "#01-map-se.cwl/sort_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#01-map-se.cwl/filtered_bed_to_bam/bam_file",
                            "id": "#01-map-se.cwl/sort_filtered_bam/input_file"
                        },
                        {
                            "source": "#01-map-se.cwl/nthreads",
                            "id": "#01-map-se.cwl/sort_filtered_bam/nthreads"
                        }
                    ],
                    "scatter": "#01-map-se.cwl/sort_filtered_bam/input_file",
                    "out": [
                        "#01-map-se.cwl/sort_filtered_bam/sorted_file"
                    ],
                    "id": "#01-map-se.cwl/sort_filtered_bam"
                }
            ],
            "id": "#01-map-se.cwl",
            "outputs": [
                {
                    "doc": "Read counts of the (unprocessed) input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/count_fastq_reads/output_read_count",
                    "id": "#01-map-se.cwl/original_fastq_read_count"
                },
                {
                    "doc": "Bowtie log file.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/bowtie-se/output_bowtie_log",
                    "id": "#01-map-se.cwl/output_bowtie_log"
                },
                {
                    "doc": "BAM files without PCR artifact reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/index_filtered_bam/indexed_file",
                    "id": "#01-map-se.cwl/output_data_filtered_bam_files"
                },
                {
                    "doc": "PCR Bottleneck Coeficient files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/execute_pcr_bottleneck_coef/pbc_file",
                    "id": "#01-map-se.cwl/output_pbc_files"
                },
                {
                    "doc": "Percentage of uniq reads from preseq c_curve output",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/percent_uniq_reads/output",
                    "id": "#01-map-se.cwl/output_percentage_uniq_reads"
                },
                {
                    "doc": "Preseq c_curve output files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/preseq-c-curve/output_file",
                    "id": "#01-map-se.cwl/output_preseq_c_curve_files"
                },
                {
                    "doc": "Read counts of the mapped BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/mapped_reads_count/output",
                    "id": "#01-map-se.cwl/output_read_count_mapped"
                },
                {
                    "doc": "Read counts of the mapped and filtered BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-map-se.cwl/mapped_filtered_reads_count/output_read_count",
                    "id": "#01-map-se.cwl/output_read_count_mapped_filtered"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "DNase-seq 02 quantification",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#02-peakcall.cwl/input_bam_files"
                },
                {
                    "default": "BAM",
                    "doc": "BAM or BAMPE for single-end and paired-end reads respectively (default: BAM)",
                    "type": "string",
                    "id": "#02-peakcall.cwl/input_bam_format"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#02-peakcall.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#count-with-output-suffix.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/peak-calling-narrow/output_peak_file",
                            "id": "#02-peakcall.cwl/count-peaks/input_file"
                        },
                        {
                            "valueFrom": ".peak_count.within_replicate.txt",
                            "id": "#02-peakcall.cwl/count-peaks/output_suffix"
                        }
                    ],
                    "scatter": "#02-peakcall.cwl/count-peaks/input_file",
                    "out": [
                        "#02-peakcall.cwl/count-peaks/output_counts"
                    ],
                    "id": "#02-peakcall.cwl/count-peaks"
                },
                {
                    "run": "#count-reads-after-filtering.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/peak-calling-narrow/output_peak_xls_file",
                            "id": "#02-peakcall.cwl/count-reads-filtered/peak_xls_file"
                        }
                    ],
                    "scatter": "#02-peakcall.cwl/count-reads-filtered/peak_xls_file",
                    "out": [
                        "#02-peakcall.cwl/count-reads-filtered/read_count_file"
                    ],
                    "id": "#02-peakcall.cwl/count-reads-filtered"
                },
                {
                    "run": "#samtools-extract-number-mapped-reads.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/filter-reads-in-peaks/filtered_file",
                            "id": "#02-peakcall.cwl/extract-count-reads-in-peaks/input_bam_file"
                        },
                        {
                            "valueFrom": ".read_count.in_peaks.within_reps.txt",
                            "id": "#02-peakcall.cwl/extract-count-reads-in-peaks/output_suffix"
                        }
                    ],
                    "scatter": "#02-peakcall.cwl/extract-count-reads-in-peaks/input_bam_file",
                    "out": [
                        "#02-peakcall.cwl/extract-count-reads-in-peaks/output_read_count"
                    ],
                    "id": "#02-peakcall.cwl/extract-count-reads-in-peaks"
                },
                {
                    "run": "#extract-best-frag-length.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/spp/output_spp_cross_corr",
                            "id": "#02-peakcall.cwl/extract-peak-frag-length/input_spp_txt_file"
                        }
                    ],
                    "scatter": "#02-peakcall.cwl/extract-peak-frag-length/input_spp_txt_file",
                    "out": [
                        "#02-peakcall.cwl/extract-peak-frag-length/output_best_frag_length"
                    ],
                    "id": "#02-peakcall.cwl/extract-peak-frag-length"
                },
                {
                    "run": "#samtools-filter-in-bedfile.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/input_bam_files",
                            "id": "#02-peakcall.cwl/filter-reads-in-peaks/input_bam_file"
                        },
                        {
                            "source": "#02-peakcall.cwl/peak-calling-narrow/output_peak_file",
                            "id": "#02-peakcall.cwl/filter-reads-in-peaks/input_bedfile"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#02-peakcall.cwl/filter-reads-in-peaks/input_bam_file",
                        "#02-peakcall.cwl/filter-reads-in-peaks/input_bedfile"
                    ],
                    "out": [
                        "#02-peakcall.cwl/filter-reads-in-peaks/filtered_file"
                    ],
                    "id": "#02-peakcall.cwl/filter-reads-in-peaks"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/bdg"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/extsize"
                        },
                        {
                            "source": "#02-peakcall.cwl/input_bam_format",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/format"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/nomodel"
                        },
                        {
                            "valueFrom": "${return 0.10}",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/q"
                        },
                        {
                            "valueFrom": "${return -100}",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/shift"
                        },
                        {
                            "source": "#02-peakcall.cwl/input_bam_files",
                            "valueFrom": "$([self])",
                            "id": "#02-peakcall.cwl/peak-calling-narrow/treatment"
                        }
                    ],
                    "scatter": [
                        "#02-peakcall.cwl/peak-calling-narrow/treatment"
                    ],
                    "out": [
                        "#02-peakcall.cwl/peak-calling-narrow/output_peak_file",
                        "#02-peakcall.cwl/peak-calling-narrow/output_ext_frag_bdg_file",
                        "#02-peakcall.cwl/peak-calling-narrow/output_peak_xls_file"
                    ],
                    "id": "#02-peakcall.cwl/peak-calling-narrow"
                },
                {
                    "run": "#spp.cwl",
                    "in": [
                        {
                            "source": "#02-peakcall.cwl/input_bam_files",
                            "id": "#02-peakcall.cwl/spp/input_bam"
                        },
                        {
                            "source": "#02-peakcall.cwl/nthreads",
                            "id": "#02-peakcall.cwl/spp/nthreads"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#02-peakcall.cwl/spp/savp"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#02-peakcall.cwl/spp/input_bam"
                    ],
                    "out": [
                        "#02-peakcall.cwl/spp/output_spp_cross_corr",
                        "#02-peakcall.cwl/spp/output_spp_cross_corr_plot"
                    ],
                    "id": "#02-peakcall.cwl/spp"
                }
            ],
            "outputs": [
                {
                    "doc": "peakshift/phantomPeak extended fragment results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/peak-calling-narrow/output_ext_frag_bdg_file",
                    "id": "#02-peakcall.cwl/output_extended_narrowpeak_file"
                },
                {
                    "doc": "Filtered read count reported by MACS2",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/count-reads-filtered/read_count_file",
                    "id": "#02-peakcall.cwl/output_filtered_read_count_file"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/peak-calling-narrow/output_peak_file",
                    "id": "#02-peakcall.cwl/output_narrowpeak_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/count-peaks/output_counts",
                    "id": "#02-peakcall.cwl/output_peak_count_within_replicate"
                },
                {
                    "doc": "Peak calling report file (*_peaks.xls file produced by MACS2)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/peak-calling-narrow/output_peak_xls_file",
                    "id": "#02-peakcall.cwl/output_peak_xls_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/extract-count-reads-in-peaks/output_read_count",
                    "id": "#02-peakcall.cwl/output_read_in_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/spp/output_spp_cross_corr_plot",
                    "id": "#02-peakcall.cwl/output_spp_cross_corr_plot"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-peakcall.cwl/spp/output_spp_cross_corr",
                    "id": "#02-peakcall.cwl/output_spp_x_cross_corr"
                }
            ],
            "id": "#02-peakcall.cwl"
        },
        {
            "class": "Workflow",
            "doc": "DNase-seq 03 quantification",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#03-quantification.cwl/input_bam_files"
                },
                {
                    "type": "File",
                    "id": "#03-quantification.cwl/input_genome_sizes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#03-quantification.cwl/input_peak_xls_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#03-quantification.cwl/input_pileup_bedgraphs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#03-quantification.cwl/input_read_count_dedup_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#03-quantification.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/input_bam_files",
                            "id": "#03-quantification.cwl/bamcoverage/bam"
                        },
                        {
                            "valueFrom": "${return 50}",
                            "id": "#03-quantification.cwl/bamcoverage/binSize"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#03-quantification.cwl/bamcoverage/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#03-quantification.cwl/bamcoverage/normalizeUsing"
                        },
                        {
                            "source": "#03-quantification.cwl/nthreads",
                            "id": "#03-quantification.cwl/bamcoverage/numberOfProcessors"
                        },
                        {
                            "valueFrom": ".norm.bw",
                            "id": "#03-quantification.cwl/bamcoverage/output_suffix"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bamcoverage/bam",
                    "out": [
                        "#03-quantification.cwl/bamcoverage/output_bam_coverage"
                    ],
                    "id": "#03-quantification.cwl/bamcoverage"
                },
                {
                    "run": "#bedGraphToBigWig.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/bedsort_clipped_bedfile/bed_file_sorted",
                            "id": "#03-quantification.cwl/bdg2bw-extend/bed_graph"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/bdg2bw-extend/genome_sizes"
                        },
                        {
                            "valueFrom": ".fragment_extended.bw",
                            "id": "#03-quantification.cwl/bdg2bw-extend/output_suffix"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bdg2bw-extend/bed_graph",
                    "out": [
                        "#03-quantification.cwl/bdg2bw-extend/output_bigwig"
                    ],
                    "id": "#03-quantification.cwl/bdg2bw-extend"
                },
                {
                    "run": "#bedGraphToBigWig.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/bedsort_scaled_bdg/bed_file_sorted",
                            "id": "#03-quantification.cwl/bdg2bw-extend-norm/bed_graph"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/bdg2bw-extend-norm/genome_sizes"
                        },
                        {
                            "valueFrom": ".fragment_extended.bw",
                            "id": "#03-quantification.cwl/bdg2bw-extend-norm/output_suffix"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bdg2bw-extend-norm/bed_graph",
                    "out": [
                        "#03-quantification.cwl/bdg2bw-extend-norm/output_bigwig"
                    ],
                    "id": "#03-quantification.cwl/bdg2bw-extend-norm"
                },
                {
                    "run": "#bedGraphToBigWig.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/bedsort_genomecov/bed_file_sorted",
                            "id": "#03-quantification.cwl/bdg2bw-raw/bed_graph"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/bdg2bw-raw/genome_sizes"
                        },
                        {
                            "valueFrom": ".raw.bw",
                            "id": "#03-quantification.cwl/bdg2bw-raw/output_suffix"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bdg2bw-raw/bed_graph",
                    "out": [
                        "#03-quantification.cwl/bdg2bw-raw/output_bigwig"
                    ],
                    "id": "#03-quantification.cwl/bdg2bw-raw"
                },
                {
                    "run": "#bedSort.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/clip-off-chrom/bed_file_clipped",
                            "id": "#03-quantification.cwl/bedsort_clipped_bedfile/bed_file"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bedsort_clipped_bedfile/bed_file",
                    "out": [
                        "#03-quantification.cwl/bedsort_clipped_bedfile/bed_file_sorted"
                    ],
                    "id": "#03-quantification.cwl/bedsort_clipped_bedfile"
                },
                {
                    "run": "#bedSort.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/bedtools_genomecov/output_bedfile",
                            "id": "#03-quantification.cwl/bedsort_genomecov/bed_file"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bedsort_genomecov/bed_file",
                    "out": [
                        "#03-quantification.cwl/bedsort_genomecov/bed_file_sorted"
                    ],
                    "id": "#03-quantification.cwl/bedsort_genomecov"
                },
                {
                    "run": "#bedSort.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/scale-bedgraph/bedgraph_scaled",
                            "id": "#03-quantification.cwl/bedsort_scaled_bdg/bed_file"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bedsort_scaled_bdg/bed_file",
                    "out": [
                        "#03-quantification.cwl/bedsort_scaled_bdg/bed_file_sorted"
                    ],
                    "id": "#03-quantification.cwl/bedsort_scaled_bdg"
                },
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#03-quantification.cwl/bedtools_genomecov/bg"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/bedtools_genomecov/g"
                        },
                        {
                            "source": "#03-quantification.cwl/input_bam_files",
                            "id": "#03-quantification.cwl/bedtools_genomecov/ibam"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/bedtools_genomecov/ibam",
                    "out": [
                        "#03-quantification.cwl/bedtools_genomecov/output_bedfile"
                    ],
                    "id": "#03-quantification.cwl/bedtools_genomecov"
                },
                {
                    "run": "#bedClip.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/extend-reads/stdoutfile",
                            "id": "#03-quantification.cwl/clip-off-chrom/bed_file"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/clip-off-chrom/genome_sizes"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/clip-off-chrom/bed_file",
                    "out": [
                        "#03-quantification.cwl/clip-off-chrom/bed_file_clipped"
                    ],
                    "id": "#03-quantification.cwl/clip-off-chrom"
                },
                {
                    "run": "#bedtools-slop.cwl",
                    "in": [
                        {
                            "valueFrom": "${return 0}",
                            "id": "#03-quantification.cwl/extend-reads/b"
                        },
                        {
                            "source": "#03-quantification.cwl/input_genome_sizes",
                            "id": "#03-quantification.cwl/extend-reads/g"
                        },
                        {
                            "source": "#03-quantification.cwl/input_pileup_bedgraphs",
                            "id": "#03-quantification.cwl/extend-reads/i"
                        }
                    ],
                    "scatter": "#03-quantification.cwl/extend-reads/i",
                    "out": [
                        "#03-quantification.cwl/extend-reads/stdoutfile"
                    ],
                    "id": "#03-quantification.cwl/extend-reads"
                },
                {
                    "run": "#scale-bedgraph.cwl",
                    "in": [
                        {
                            "source": "#03-quantification.cwl/input_pileup_bedgraphs",
                            "id": "#03-quantification.cwl/scale-bedgraph/bedgraph_file"
                        },
                        {
                            "source": "#03-quantification.cwl/input_read_count_dedup_files",
                            "id": "#03-quantification.cwl/scale-bedgraph/read_count_file"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-quantification.cwl/scale-bedgraph/bedgraph_file",
                        "#03-quantification.cwl/scale-bedgraph/read_count_file"
                    ],
                    "out": [
                        "#03-quantification.cwl/scale-bedgraph/bedgraph_scaled"
                    ],
                    "id": "#03-quantification.cwl/scale-bedgraph"
                }
            ],
            "outputs": [
                {
                    "doc": "Fragment extended reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-quantification.cwl/bdg2bw-extend/output_bigwig",
                    "id": "#03-quantification.cwl/bigwig_extended_files"
                },
                {
                    "doc": "Normalized fragment extended reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-quantification.cwl/bdg2bw-extend-norm/output_bigwig",
                    "id": "#03-quantification.cwl/bigwig_extended_norm_files"
                },
                {
                    "doc": "Normalized reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-quantification.cwl/bamcoverage/output_bam_coverage",
                    "id": "#03-quantification.cwl/bigwig_norm_files"
                },
                {
                    "doc": "Raw reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-quantification.cwl/bdg2bw-raw/output_bigwig",
                    "id": "#03-quantification.cwl/bigwig_raw_files"
                }
            ],
            "id": "#03-quantification.cwl"
        },
        {
            "class": "Workflow",
            "doc": "DNase-seq pipeline - reads: SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#main/ENCODE_blacklist_bedfile"
                },
                {
                    "doc": "Adapters file",
                    "type": "File",
                    "id": "#main/default_adapters_file"
                },
                {
                    "doc": "\"First index file of Bowtie reference genome with extension 1.ebwt. \\ (Note: the rest of the index files MUST be in the same folder)\" ",
                    "type": "File",
                    "id": "#main/genome_ref_first_index_file"
                },
                {
                    "doc": "Genome sizes tab-delimited file (used in samtools)",
                    "type": "File",
                    "id": "#main/genome_sizes_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_fastq_files"
                },
                {
                    "doc": "Number of threads required for the 03-map step",
                    "type": "int",
                    "id": "#main/nthreads_map"
                },
                {
                    "doc": "Number of threads required for the 04-peakcall step",
                    "type": "int",
                    "id": "#main/nthreads_peakcall"
                },
                {
                    "doc": "Number of threads required for the 05-quantification step",
                    "type": "int",
                    "id": "#main/nthreads_quant"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/map/ENCODE_blacklist_bedfile"
                        },
                        {
                            "source": "#main/genome_ref_first_index_file",
                            "id": "#main/map/genome_ref_first_index_file"
                        },
                        {
                            "source": "#main/genome_sizes_file",
                            "id": "#main/map/genome_sizes_file"
                        },
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/map/input_fastq_files"
                        },
                        {
                            "source": "#main/nthreads_map",
                            "id": "#main/map/nthreads"
                        }
                    ],
                    "run": "#01-map-se.cwl",
                    "out": [
                        "#main/map/output_data_filtered_bam_files",
                        "#main/map/output_pbc_files",
                        "#main/map/output_bowtie_log",
                        "#main/map/output_preseq_c_curve_files",
                        "#main/map/original_fastq_read_count",
                        "#main/map/output_read_count_mapped",
                        "#main/map/output_read_count_mapped_filtered",
                        "#main/map/output_percentage_uniq_reads"
                    ],
                    "id": "#main/map"
                },
                {
                    "in": [
                        {
                            "source": "#main/map/output_data_filtered_bam_files",
                            "id": "#main/peak_call/input_bam_files"
                        },
                        {
                            "valueFrom": "BAM",
                            "id": "#main/peak_call/input_bam_format"
                        },
                        {
                            "source": "#main/nthreads_peakcall",
                            "id": "#main/peak_call/nthreads"
                        }
                    ],
                    "run": "#02-peakcall.cwl",
                    "out": [
                        "#main/peak_call/output_spp_x_cross_corr",
                        "#main/peak_call/output_spp_cross_corr_plot",
                        "#main/peak_call/output_narrowpeak_file",
                        "#main/peak_call/output_extended_narrowpeak_file",
                        "#main/peak_call/output_peak_xls_file",
                        "#main/peak_call/output_filtered_read_count_file",
                        "#main/peak_call/output_peak_count_within_replicate",
                        "#main/peak_call/output_read_in_peak_count_within_replicate"
                    ],
                    "id": "#main/peak_call"
                },
                {
                    "in": [
                        {
                            "source": "#main/map/output_data_filtered_bam_files",
                            "id": "#main/quant/input_bam_files"
                        },
                        {
                            "source": "#main/genome_sizes_file",
                            "id": "#main/quant/input_genome_sizes"
                        },
                        {
                            "source": "#main/peak_call/output_peak_xls_file",
                            "id": "#main/quant/input_peak_xls_files"
                        },
                        {
                            "source": "#main/peak_call/output_extended_narrowpeak_file",
                            "id": "#main/quant/input_pileup_bedgraphs"
                        },
                        {
                            "source": "#main/peak_call/output_read_in_peak_count_within_replicate",
                            "id": "#main/quant/input_read_count_dedup_files"
                        },
                        {
                            "source": "#main/nthreads_quant",
                            "id": "#main/quant/nthreads"
                        }
                    ],
                    "run": "#03-quantification.cwl",
                    "out": [
                        "#main/quant/bigwig_raw_files",
                        "#main/quant/bigwig_norm_files",
                        "#main/quant/bigwig_extended_files",
                        "#main/quant/bigwig_extended_norm_files"
                    ],
                    "id": "#main/quant"
                }
            ],
            "outputs": [
                {
                    "doc": "Read counts of the (unprocessed) input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/original_fastq_read_count",
                    "id": "#main/fastq_read_count"
                },
                {
                    "doc": "Bowtie log file with mapping stats",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_bowtie_log",
                    "id": "#main/map_bowtie_log_files"
                },
                {
                    "doc": "Filtered BAM files (post-processing end point)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_data_filtered_bam_files",
                    "id": "#main/map_filtered_bam_files"
                },
                {
                    "doc": "Read counts of the mapped and filtered BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_read_count_mapped_filtered",
                    "id": "#main/map_filtered_read_count"
                },
                {
                    "doc": "PCR Bottleneck Coefficient files (used to flag samples when pbc<0.5)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_pbc_files",
                    "id": "#main/map_pbc_files"
                },
                {
                    "doc": "Percentage of uniq reads from preseq c_curve output",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_percentage_uniq_reads",
                    "id": "#main/map_percentage_uniq_reads"
                },
                {
                    "doc": "Preseq c_curve output files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_preseq_c_curve_files",
                    "id": "#main/map_preseq_c_curve_files"
                },
                {
                    "doc": "Read counts of the mapped BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_read_count_mapped",
                    "id": "#main/map_read_count"
                },
                {
                    "doc": "Extended fragment peaks in narrowPeak file format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_extended_narrowpeak_file",
                    "id": "#main/peak_call_extended_narrowpeak_file"
                },
                {
                    "doc": "Filtered read count after peak calling",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_filtered_read_count_file",
                    "id": "#main/peak_call_filtered_read_count_file"
                },
                {
                    "doc": "Peaks in narrowPeak file format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_narrowpeak_file",
                    "id": "#main/peak_call_narrowpeak_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_count_within_replicate",
                    "id": "#main/peak_call_peak_count_within_replicate"
                },
                {
                    "doc": "Peak calling report file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_xls_file",
                    "id": "#main/peak_call_peak_xls_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_read_in_peak_count_within_replicate",
                    "id": "#main/peak_call_read_in_peak_count_within_replicate"
                },
                {
                    "doc": "SPP strand cross correlation summary",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_spp_x_cross_corr",
                    "id": "#main/peak_call_spp_x_cross_corr"
                },
                {
                    "doc": "SPP strand cross correlation plot",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_spp_cross_corr_plot",
                    "id": "#main/peak_call_spp_x_cross_corr_plot"
                },
                {
                    "doc": "Fragment extended reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_extended_files",
                    "id": "#main/quant_bigwig_extended_files"
                },
                {
                    "doc": "Normalized fragment extended reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_extended_norm_files",
                    "id": "#main/quant_bigwig_extended_norm_files"
                },
                {
                    "doc": "Normalized reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_norm_files",
                    "id": "#main/quant_bigwig_norm_files"
                },
                {
                    "doc": "Raw reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_raw_files",
                    "id": "#main/quant_bigwig_raw_files"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-i"
                    },
                    "doc": "Input BAM file to be converted to BED format",
                    "id": "#bedtools-bamtobed.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed12"
                    },
                    "doc": "Write \"blocked\" BED format (aka \"BED12\"). Forces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/bed12"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "Write BEDPE format.\n- Requires BAM to be grouped or sorted by query.\n",
                    "id": "#bedtools-bamtobed.cwl/bedpe"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-cigar"
                    },
                    "doc": "Add the CIGAR string to the BED entry as a 7th column.\n",
                    "id": "#bedtools-bamtobed.cwl/cigar"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-color"
                    },
                    "doc": "An R,G,B string for the color used with BED12 format.\nDefault is (255,0,0).\n",
                    "id": "#bedtools-bamtobed.cwl/color"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ed"
                    },
                    "doc": "Use BAM edit distance (NM tag) for BED score.\n- Default for BED is to use mapping quality.\n- Default for BEDPE is to use the minimum of\nthe two mapping qualities for the pair.\n- When -ed is used with -bedpe, the total edit\ndistance from the two mates is reported.\n",
                    "id": "#bedtools-bamtobed.cwl/ed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mate1"
                    },
                    "doc": "When writing BEDPE (-bedpe) format, \nalways report mate one as the first BEDPE \"block\".\n",
                    "id": "#bedtools-bamtobed.cwl/mate1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Report \"split\" BAM alignments as separate BED entries.\nSplits only on N CIGAR operations.\n",
                    "id": "#bedtools-bamtobed.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-splitD"
                    },
                    "doc": "Split alignments based on N and D CIGAR operators.\nForces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/splitD"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-tag"
                    },
                    "doc": "Use other NUMERIC BAM alignment tag for BED score.\n- Default for BED is to use mapping quality.\nDisallowed with BEDPE output.\n",
                    "id": "#bedtools-bamtobed.cwl/tag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')"
                    },
                    "id": "#bedtools-bamtobed.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bamtobed"
            ],
            "stdout": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')",
            "id": "#bedtools-bamtobed.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools bedtobam (aka bedToBam)\nVersion: v2.25.0\nSummary: Converts feature records to BAM format.\n\nUsage:   bedtools bedtobam [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions: \n\t-mapq\tSet the mappinq quality for the BAM records.\n\t\t(INT) Default: 255\n\n\t-bed12\tThe BED file is in BED12 format.  The BAM CIGAR\n\t\tstring will reflect BED \"blocks\".\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\nNotes: \n\t(1)  BED files must be at least BED4 to create BAM (needs name field).",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed12"
                    },
                    "doc": "The BED file is in BED12 format.  The BAM CIGAR\nstring will reflect BED \"blocks\".\n",
                    "id": "#bedtools-bedtobam.cwl/bed12"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-g"
                    },
                    "doc": "Genome chromosome sizes file",
                    "id": "#bedtools-bedtobam.cwl/g"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-i"
                    },
                    "doc": "Input <bed/gff/vcf> file to be converted to BAM format",
                    "id": "#bedtools-bedtobam.cwl/i"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mapq"
                    },
                    "doc": "Set the mappinq quality for the BAM records.\n(INT) Default: 255\n",
                    "id": "#bedtools-bedtobam.cwl/mapq"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    },
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "id": "#bedtools-bedtobam.cwl/ubam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.i.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bam')"
                    },
                    "id": "#bedtools-bedtobam.cwl/bam_file"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bedtobam"
            ],
            "stdout": "$(inputs.i.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bam')",
            "id": "#bedtools-bedtobam.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools genomecov (aka genomeCoverageBed)\nVersion: v2.25.0\nSummary: Compute the coverage of a feature file among a genome.\n\nUsage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions: \n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero \n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0 \n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations \n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6). \n\t\t\t- (STRING): can be + or -\n\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes: \n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips: \n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-3"
                    },
                    "doc": "\tCalculate coverage of 3\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-5"
                    },
                    "doc": "\tCalculate coverage of 5\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/5"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bg"
                    },
                    "doc": "\tReport depth in BedGraph format. For details, see:\ngenome.ucsc.edu/goldenPath/help/bedgraph.html\n",
                    "id": "#bedtools-genomecov.cwl/bg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bga"
                    },
                    "doc": "\tReport depth in BedGraph format, as above (-bg).\nHowever with this option, regions with zero\ncoverage are also reported. This allows one to\nquickly extract all regions of a genome with 0\ncoverage by applying: \"grep -w 0$\" to the output.\n",
                    "id": "#bedtools-genomecov.cwl/bga"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "doc": "\tReport the depth at each genome position (with one-based coordinates).\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-dz"
                    },
                    "doc": "\tReport the depth at each genome position (with zero-based coordinates).\nReports only non-zero positions.\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/dz"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-g"
                    },
                    "doc": "<genome sizes>",
                    "id": "#bedtools-genomecov.cwl/g"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-ibam"
                    },
                    "doc": "\tThe input file is in BAM format.\nNote: BAM _must_ be sorted by position\n",
                    "id": "#bedtools-genomecov.cwl/ibam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-max"
                    },
                    "doc": "\tCombine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-scale"
                    },
                    "doc": "\tScale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-strand"
                    },
                    "doc": "\tCalculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackline"
                    },
                    "doc": "Adds a UCSC/Genome-Browser track line definition in the first line of the output.\n- See here for more details about track line definition:\nhttp://genome.ucsc.edu/goldenPath/help/bedgraph.html\n- NOTE: When adding a trackline definition, the output BedGraph can be easily\nuploaded to the Genome Browser as a custom track,\nBUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n",
                    "id": "#bedtools-genomecov.cwl/trackline"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackopts"
                    },
                    "doc": "Writes additional track line definition parameters in the first line.\n- Example:\n-trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\nNote the use of single-quotes if you have spaces in your parameters.\n- (TEXT)\n",
                    "id": "#bedtools-genomecov.cwl/trackopts"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')"
                    },
                    "id": "#bedtools-genomecov.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "stdout": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')",
            "id": "#bedtools-genomecov.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools intersect (aka intersectBed)\nVersion: v2.25.0\nSummary: Report overlaps between two feature files.\n\nUsage:   bedtools intersect [OPTIONS] -a <bed/gff/vcf/bam> -b <bed/gff/vcf/bam>\n\n\tNote: -b may be followed with multiple databases and/or \n\twildcard (*) character(s). \nOptions: \n\t-wa\tWrite the original entry in A for each overlap.\n\n\t-wb\tWrite the original entry in B for each overlap.\n\t\t- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n\n\t-loj\tPerform a \"left outer join\". That is, for each feature in A\n\t\treport each overlap with B.  If no overlaps are found, \n\t\treport a NULL feature for B.\n\n\t-wo\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlaps restricted by -f and -r.\n\t\t  Only A features with overlap are reported.\n\n\t-wao\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlapping features restricted by -f and -r.\n\t\t  However, A features w/o overlap are also reported\n\t\t  with a NULL B feature and overlap = 0.\n\n\t-u\tWrite the original A entry _once_ if _any_ overlaps found in B.\n\t\t- In other words, just report the fact >=1 hit was found.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-c\tFor each entry in A, report the number of overlaps with B.\n\t\t- Reports 0 for A entries that have no overlap with B.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-v\tOnly report those entries in A that have _no overlaps_ with B.\n\t\t- Similar to \"grep -v\" (an homage).\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n\t-s\tRequire same strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _same_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-S\tRequire different strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _opposite_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-f\tMinimum overlap required as a fraction of A.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-F\tMinimum overlap required as a fraction of B.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-r\tRequire that the fraction overlap be reciprocal for A AND B.\n\t\t- In other words, if -f is 0.90 and -r is used, this requires\n\t\t  that B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n\n\t-e\tRequire that the minimum fraction be satisfied for A OR B.\n\t\t- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\n\t\t  that either 90 percent of A is covered OR 10 percent of  B is covered.\n\t\t  Without -e, both fractions would have to be satisfied.\n\n\t-split\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\n\t-g\tProvide a genome file to enforce consistent chromosome sort order\n\t\tacross input files. Only applies when used with -sorted option.\n\n\t-nonamecheck\tFor sorted data, don't throw an error if the file has different naming conventions\n\t\t\tfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n\n\t-sorted\tUse the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n\n\t-names\tWhen using multiple databases, provide an alias for each that\n\t\twill appear instead of a fileId when also printing the DB record.\n\n\t-filenames\tWhen using multiple databases, show each complete filename\n\t\t\tinstead of a fileId when also printing the DB record.\n\n\t-sortout\tWhen using multiple databases, sort the output DB hits\n\t\t\tfor each record.\n\n\t-bed\tIf using BAM input, write output as BED.\n\n\t-header\tPrint the header from the A file prior to results.\n\n\t-nobuf\tDisable buffered output. Using this option will cause each line\n\t\tof output to be printed as it is generated, rather than saved\n\t\tin a buffer. This will make printing large output files \n\t\tnoticeably slower, but can be useful in conjunction with\n\t\tother software tools and scripts that need to process one\n\t\tline of bedtools output at a time.\n\n\t-iobuf\tSpecify amount of memory to use for input buffer.\n\t\tTakes an integer argument. Optional suffixes K/M/G supported.\n\t\tNote: currently has no effect with compressed files.\n\nNotes: \n\t(1) When a BAM file is used for the A file, the alignment is retained if overlaps exist,\n\tand exlcuded if an overlap cannot be found.  If multiple overlaps exist, they are not\n\treported, as we are only testing for one or more overlaps.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "Minimum overlap required as a fraction of B.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "id": "#bedtools-intersect.cwl/F"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Require different strandedness.  That is, only report hits in B\nthat overlap A on the _opposite_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "id": "#bedtools-intersect.cwl/S"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "Input <bed/gff/vcf/bam> file",
                    "id": "#bedtools-intersect.cwl/a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-b"
                    },
                    "doc": "<bed/gff/vcf/bam>",
                    "id": "#bedtools-intersect.cwl/b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed"
                    },
                    "doc": "If using BAM input, write output as BED.\n",
                    "id": "#bedtools-intersect.cwl/bed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "For each entry in A, report the number of overlaps with B.\n- Reports 0 for A entries that have no overlap with B.\n- Overlaps restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    },
                    "doc": "Require that the minimum fraction be satisfied for A OR B.\n- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\nthat either 90 percent of A is covered OR 10 percent of  B is covered.\nWithout -e, both fractions would have to be satisfied.\n",
                    "id": "#bedtools-intersect.cwl/e"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "Minimum overlap required as a fraction of A.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "id": "#bedtools-intersect.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-filenames"
                    },
                    "doc": "When using multiple databases, show each complete filename\ninstead of a fileId when also printing the DB record.\n",
                    "id": "#bedtools-intersect.cwl/filenames"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "Provide a genome file to enforce consistent chromosome sort order\nacross input files. Only applies when used with -sorted option.\n",
                    "id": "#bedtools-intersect.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-header"
                    },
                    "doc": "Print the header from the A file prior to results.\n",
                    "id": "#bedtools-intersect.cwl/header"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-iobuf"
                    },
                    "doc": "Specify amount of memory to use for input buffer.\nTakes an integer argument. Optional suffixes K/M/G supported.\nNote: currently has no effect with compressed files.\n",
                    "id": "#bedtools-intersect.cwl/iobuf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-loj"
                    },
                    "doc": "Perform a \"left outer join\". That is, for each feature in A\nreport each overlap with B.  If no overlaps are found,\nreport a NULL feature for B.\n",
                    "id": "#bedtools-intersect.cwl/loj"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-names"
                    },
                    "doc": "When using multiple databases, provide an alias for each that\nwill appear instead of a fileId when also printing the DB record.\n",
                    "id": "#bedtools-intersect.cwl/names"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nobuf"
                    },
                    "doc": "Disable buffered output. Using this option will cause each line\nof output to be printed as it is generated, rather than saved\nin a buffer. This will make printing large output files\nnoticeably slower, but can be useful in conjunction with\nother software tools and scripts that need to process one\nline of bedtools output at a time.\n",
                    "id": "#bedtools-intersect.cwl/nobuf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nonamecheck"
                    },
                    "doc": "For sorted data, don't throw an error if the file has different naming conventions\nfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n",
                    "id": "#bedtools-intersect.cwl/nonamecheck"
                },
                {
                    "type": "string",
                    "id": "#bedtools-intersect.cwl/output_basename_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "Require that the fraction overlap be reciprocal for A AND B.\n- In other words, if -f is 0.90 and -r is used, this requires\nthat B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n",
                    "id": "#bedtools-intersect.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "Require same strandedness.  That is, only report hits in B\nthat overlap A on the _same_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "id": "#bedtools-intersect.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sorted"
                    },
                    "doc": "Use the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n",
                    "id": "#bedtools-intersect.cwl/sorted"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sortout"
                    },
                    "doc": "When using multiple databases, sort the output DB hits\nfor each record.\n",
                    "id": "#bedtools-intersect.cwl/sortout"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Treat \"split\" BAM or BED12 entries as distinct BED intervals.\n",
                    "id": "#bedtools-intersect.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "Write the original A entry _once_ if _any_ overlaps found in B.\n- In other words, just report the fact >=1 hit was found.\n- Overlaps restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/u"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    },
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "id": "#bedtools-intersect.cwl/ubam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "Only report those entries in A that have _no overlaps_ with B.\n- Similar to \"grep -v\" (an homage).\n",
                    "id": "#bedtools-intersect.cwl/v"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wa"
                    },
                    "doc": "Write the original entry in A for each overlap.\n",
                    "id": "#bedtools-intersect.cwl/wa"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wao"
                    },
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlapping features restricted by -f and -r.\nHowever, A features w/o overlap are also reported\nwith a NULL B feature and overlap = 0.\n",
                    "id": "#bedtools-intersect.cwl/wao"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wb"
                    },
                    "doc": "Write the original entry in B for each overlap.\n- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/wb"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wo"
                    },
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlaps restricted by -f and -r.\nOnly A features with overlap are reported.\n",
                    "id": "#bedtools-intersect.cwl/wo"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_basename_file + '.masked.bam')"
                    },
                    "id": "#bedtools-intersect.cwl/file_wo_blacklist_regions"
                }
            ],
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "stdout": "$(inputs.output_basename_file + '.masked.bam')",
            "id": "#bedtools-intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get number of processed reads from Bowtie log.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {},
                    "id": "#bowtie-log-read-count.cwl/bowtie_log"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bowtie_log.path.replace(/^.*[\\\\\\/]/, '') + '.read_count.mapped')"
                    },
                    "id": "#bowtie-log-read-count.cwl/output"
                }
            ],
            "baseCommand": "read-count-from-bowtie-log.sh",
            "stdout": "$(inputs.bowtie_log.path.replace(/^.*[\\\\\\/]/, '') + '.read_count.mapped')",
            "id": "#bowtie-log-read-count.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/bowtie:1.2.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-X"
                    },
                    "doc": "maximum insert size for paired-end alignment (default: 250)",
                    "id": "#bowtie-se.cwl/X"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--best"
                    },
                    "doc": "Hits guaranteed best stratum; ties broken by quality",
                    "id": "#bowtie-se.cwl/best"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--chunkmbs"
                    },
                    "doc": "The number of megabytes of memory a given thread is given to store path descriptors in --best mode. (Default: 256)",
                    "id": "#bowtie-se.cwl/chunkmbs"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.ebwt",
                        "^^.3.ebwt",
                        "^^.4.ebwt",
                        "^^.rev.1.ebwt",
                        "^^.rev.2.ebwt"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "valueFrom": "$(self.path.split('.').splice(0,self.path.split('.').length-2).join(\".\"))"
                    },
                    "doc": "First file (extension .1.ebwt) of the Bowtie index files generated for the reference genome (see http://bowtie-bio.sourceforge.net/tutorial.shtml#newi)",
                    "id": "#bowtie-se.cwl/genome_ref_first_index_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "doc": "Query input FASTQ file.",
                    "id": "#bowtie-se.cwl/input_fastq_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-m"
                    },
                    "doc": "Suppress all alignments if > <int> exist (def: 1)",
                    "id": "#bowtie-se.cwl/m"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--threads"
                    },
                    "doc": "<int> number of alignment threads to launch (default: 1)",
                    "id": "#bowtie-se.cwl/nthreads"
                },
                {
                    "type": "string",
                    "id": "#bowtie-se.cwl/output_filename"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--sam"
                    },
                    "doc": "Write hits in SAM format (default: BAM)",
                    "id": "#bowtie-se.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedlen"
                    },
                    "doc": "seed length for -n (default: 28)",
                    "id": "#bowtie-se.cwl/seedlen"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedmms"
                    },
                    "doc": "max mismatches in seed (between [0, 3], default: 2)",
                    "id": "#bowtie-se.cwl/seedmms"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--strata"
                    },
                    "doc": "Hits in sub-optimal strata aren't reported (requires --best)",
                    "id": "#bowtie-se.cwl/strata"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "Print wall-clock time taken by search phases",
                    "id": "#bowtie-se.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim3"
                    },
                    "doc": "trim <int> bases from 3' (right) end of reads",
                    "id": "#bowtie-se.cwl/trim3"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim5"
                    },
                    "doc": "trim <int> bases from 5' (left) end of reads",
                    "id": "#bowtie-se.cwl/trim5"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-v"
                    },
                    "doc": "Report end-to-end hits w/ <=v mismatches; ignore qualities",
                    "id": "#bowtie-se.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.sam')"
                    },
                    "doc": "Aligned bowtie file in [SAM|BAM] format.",
                    "id": "#bowtie-se.cwl/output_aligned_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.bowtie.log')"
                    },
                    "id": "#bowtie-se.cwl/output_bowtie_log"
                }
            ],
            "baseCommand": "bowtie",
            "stderr": "$(inputs.output_filename + '.bowtie.log')",
            "arguments": [
                {
                    "valueFrom": "$(inputs.output_filename + '.sam')",
                    "position": 11
                }
            ],
            "id": "#bowtie-se.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compute PCR Bottleneck Coeficient from BedGraph file.",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#compute-pbc.cwl/bedgraph_file"
                },
                {
                    "type": "string",
                    "id": "#compute-pbc.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.PBC.txt')"
                    },
                    "id": "#compute-pbc.cwl/pbc"
                }
            ],
            "baseCommand": [
                "awk",
                "$4==1 {N1 += $3 - $2}; $4>=1 {Nd += $3 - $2} END {print N1/Nd}"
            ],
            "stdout": "$(inputs.output_filename + '.PBC.txt')",
            "id": "#compute-pbc.cwl"
        },
        {
            "class": "Workflow",
            "doc": "DNase-seq - map - Filter PCR Artifacts",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#filter-pcr-artifacts.cwl/input_bam_files"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-bamtobed.cwl",
                    "in": [
                        {
                            "source": "#filter-pcr-artifacts.cwl/input_bam_files",
                            "id": "#filter-pcr-artifacts.cwl/bedtools_bamtobed/bam"
                        }
                    ],
                    "scatter": "#filter-pcr-artifacts.cwl/bedtools_bamtobed/bam",
                    "out": [
                        "#filter-pcr-artifacts.cwl/bedtools_bamtobed/output_bedfile"
                    ],
                    "id": "#filter-pcr-artifacts.cwl/bedtools_bamtobed"
                },
                {
                    "run": "#windowtrimmer.cwl",
                    "in": [
                        {
                            "source": "#filter-pcr-artifacts.cwl/bedtools_bamtobed/output_bedfile",
                            "id": "#filter-pcr-artifacts.cwl/window_trimmer/input_file"
                        }
                    ],
                    "scatter": "#filter-pcr-artifacts.cwl/window_trimmer/input_file",
                    "out": [
                        "#filter-pcr-artifacts.cwl/window_trimmer/filtered_file"
                    ],
                    "id": "#filter-pcr-artifacts.cwl/window_trimmer"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#filter-pcr-artifacts.cwl/window_trimmer/filtered_file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#filter-pcr-artifacts.cwl/filtered_bedfile"
                }
            ],
            "id": "#filter-pcr-artifacts.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ChIP-seq - map - PCR Bottleneck Coefficients",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#pcr-bottleneck-coef.cwl/genome_sizes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/input_bam_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/input_output_filenames"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/bg"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/genome_sizes",
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/g"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/input_bam_files",
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/ibam"
                        }
                    ],
                    "scatter": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/ibam",
                    "out": [
                        "#pcr-bottleneck-coef.cwl/bedtools_genomecov/output_bedfile"
                    ],
                    "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov"
                },
                {
                    "run": "#compute-pbc.cwl",
                    "in": [
                        {
                            "source": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/output_bedfile",
                            "id": "#pcr-bottleneck-coef.cwl/compute_pbc/bedgraph_file"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/input_output_filenames",
                            "id": "#pcr-bottleneck-coef.cwl/compute_pbc/output_filename"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#pcr-bottleneck-coef.cwl/compute_pbc/bedgraph_file",
                        "#pcr-bottleneck-coef.cwl/compute_pbc/output_filename"
                    ],
                    "out": [
                        "#pcr-bottleneck-coef.cwl/compute_pbc/pbc"
                    ],
                    "id": "#pcr-bottleneck-coef.cwl/compute_pbc"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#pcr-bottleneck-coef.cwl/compute_pbc/pbc",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/pbc_file"
                }
            ],
            "id": "#pcr-bottleneck-coef.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Usage: c_curve [OPTIONS] <sorted-bed-file>\n\nOptions:\n  -o, -output   yield output file (default: stdout) \n  -s, -step     step size in extrapolations (default: 1e+06) \n  -v, -verbose  print more information \n  -P, -pe       input is paired end read file \n  -H, -hist     input is a text file containing the observed histogram \n  -V, -vals     input is a text file containing only the observed counts \n  -B, -bam      input is in BAM format \n  -l, -seg_len  maximum segment length when merging paired end bam reads \n                (default: 5000) \n\nHelp options:\n  -?, -help     print this help message \n      -about    print about message",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/preseq:2.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "-bam      input is in BAM format \n",
                    "id": "#preseq-c_curve.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-H"
                    },
                    "doc": "-hist     input is a text file containing the observed histogram \n",
                    "id": "#preseq-c_curve.cwl/H"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-V"
                    },
                    "doc": "-vals     input is a text file containing only the observed counts \n",
                    "id": "#preseq-c_curve.cwl/V"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sorted bed or BAM file",
                    "id": "#preseq-c_curve.cwl/input_sorted_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "-seg_len  maximum segment length when merging paired end bam reads \n(default: 5000)\nHelp options:\n-?, -help     print this help message\n-about    print about message\n",
                    "id": "#preseq-c_curve.cwl/l"
                },
                {
                    "type": "string",
                    "id": "#preseq-c_curve.cwl/output_file_basename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-P"
                    },
                    "doc": "-pe       input is paired end read file \n",
                    "id": "#preseq-c_curve.cwl/pe"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "-step     step size in extrapolations (default: 1e+06) \n",
                    "id": "#preseq-c_curve.cwl/s"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "-verbose  print more information \n",
                    "id": "#preseq-c_curve.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_basename + '.preseq_c_curve.txt')"
                    },
                    "id": "#preseq-c_curve.cwl/output_file"
                }
            ],
            "baseCommand": [
                "preseq",
                "c_curve"
            ],
            "stdout": "$(inputs.output_file_basename + '.preseq_c_curve.txt')",
            "id": "#preseq-c_curve.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get number of processed reads from Bowtie log.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {},
                    "id": "#preseq-percent-uniq-reads.cwl/preseq_c_curve_outfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.preseq_c_curve_outfile.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.percentage_unique_reads.txt')"
                    },
                    "id": "#preseq-percent-uniq-reads.cwl/output"
                }
            ],
            "baseCommand": "percent-uniq-reads-from-preseq.sh",
            "stdout": "$(inputs.preseq_c_curve_outfile.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.percentage_unique_reads.txt')",
            "id": "#preseq-percent-uniq-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-filter-unmapped.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-filter-unmapped.cwl/nthreads"
                },
                {
                    "type": "string",
                    "doc": "Basename for the output file",
                    "id": "#samtools-filter-unmapped.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.accepted_hits.bam')"
                    },
                    "doc": "Filter unmapped reads in aligned file",
                    "id": "#samtools-filter-unmapped.cwl/filtered_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-F",
                "4",
                "-b",
                "-h"
            ],
            "stdout": "$(inputs.output_filename + '.accepted_hits.bam')",
            "id": "#samtools-filter-unmapped.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.input_file)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-index.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "doc": "Indexed BAM file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename)"
                    },
                    "secondaryFiles": ".bai",
                    "id": "#samtools-index.cwl/indexed_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_file.basename + '.bai')",
                    "position": 2
                }
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-sort.cwl/input_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "Sort by read name",
                    "id": "#samtools-sort.cwl/n"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": ".sorted.bam",
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-sort.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)"
                    },
                    "doc": "Sorted aligned file",
                    "id": "#samtools-sort.cwl/sorted_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 3,
                    "prefix": "-T"
                }
            ],
            "id": "#samtools-sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Input format autodetected",
                    "id": "#samtools2bam.cwl/S"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "File to be converted to BAM with samtools",
                    "id": "#samtools2bam.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used",
                    "id": "#samtools2bam.cwl/nthreads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bam')"
                    },
                    "doc": "Aligned file in BAM format",
                    "id": "#samtools2bam.cwl/bam_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bam')",
            "id": "#samtools2bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter out reads from a BED file that are too concentrated within a base-pair window.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/windowtrimmer",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "CUTOFF\n        threshold for concentration at a single base\n        within a window to cutoff\n",
                    "id": "#windowtrimmer.cwl/cutoff"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "doc": "BED file containing the reads to be filter.",
                    "id": "#windowtrimmer.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-w"
                    },
                    "doc": "WINDOWSIZE\n        Window size threshold for trimming reads that have the same mapping start position.\n",
                    "id": "#windowtrimmer.cwl/window_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.filtered.bed')"
                    },
                    "doc": "Filtered BED file",
                    "id": "#windowtrimmer.cwl/filtered_file"
                }
            ],
            "baseCommand": "windowTrimmer.py",
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.filtered.bed')",
            "id": "#windowtrimmer.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Count number of dedup-ed reads used in peak calling",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-reads-after-filtering.cwl/peak_xls_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))"
                    },
                    "id": "#count-reads-after-filtering.cwl/read_count_file"
                }
            ],
            "baseCommand": "count-filtered-reads-macs2.sh",
            "stdout": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))",
            "id": "#count-reads-after-filtering.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/macs2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--SPMR"
                    },
                    "doc": "If True, MACS will save signal per million reads for fragment pileup profiles. Require --bdg to be set. Default: False ",
                    "id": "#macs2-callpeak.cwl/SPMR"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bdg"
                    },
                    "doc": "Whether or not to save extended fragment pileup, and local lambda tracks (two files) at every bp into a bedGraph file. DEFAULT: True",
                    "id": "#macs2-callpeak.cwl/bdg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad"
                    },
                    "doc": "If set, MACS will try to call broad peaks by linking nearby highly enriched regions. The linking region is controlled by another cutoff through --linking-cutoff. The maximum linking region length is 4 times of d from MACS. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/broad"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad-cutoff"
                    },
                    "doc": "BROADCUTOFF\nCutoff for broad region. This option is not available\nunless --broad is set. If -p is set, this is a pvalue\ncutoff, otherwise, it's a qvalue cutoff. DEFAULT: 0.1\n",
                    "id": "#macs2-callpeak.cwl/broad-cutoff"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--buffer-size"
                    },
                    "doc": "BUFFER_SIZE\nBuffer size for incrementally increasing internal\narray size to store reads alignment information. In\nmost cases, you don't have to change this parameter.\nHowever, if there are large number of\nchromosomes/contigs/scaffolds in your alignment, it's\nrecommended to specify a smaller buffer size in order\nto decrease memory usage (but it will take longer time\nto read alignment files). Minimum memory requested for\nreading an alignment file is about # of CHROMOSOME *\nBUFFER_SIZE * 2 Bytes. DEFAULT: 100000\n",
                    "id": "#macs2-callpeak.cwl/buffer-size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bw"
                    },
                    "doc": "BW               Band width for picking regions to compute fragment\nsize. This value is only used while building the\nshifting model. DEFAULT: 300\n",
                    "id": "#macs2-callpeak.cwl/bw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--call-summits"
                    },
                    "doc": "If set, MACS will use a more sophisticated signal processing approach to find subpeak summits in each enriched peak region. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/call-summits"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--control"
                    },
                    "doc": "Control sample file.",
                    "id": "#macs2-callpeak.cwl/control"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--cutoff-analysis"
                    },
                    "doc": "While set, MACS2 will analyze number or total length of peaks that can be called by different p-value cutoff then output a summary table to help user decide a better cutoff. The table will be saved in NAME_cutoff_analysis.txt file. Note, minlen and maxgap may affect the results. WARNING: May take ~30 folds longer time to finish. DEFAULT: False Post-processing options: ",
                    "id": "#macs2-callpeak.cwl/cutoff-analysis"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--down-sample"
                    },
                    "doc": "When set, random sampling method will scale down the bigger sample. By default, MACS uses linear scaling. Warning: This option will make your result unstable and irreproducible since each time, random reads would be selected. Consider to use 'randsample' script instead. <not implmented>If used together with --SPMR, 1 million unique reads will be randomly picked.</not implemented> Caution: due to the implementation, the final number of selected reads may not be as you expected! DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/down-sample"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extsize"
                    },
                    "doc": "The arbitrary extension size in bp. When nomodel is  true, MACS will use this value as fragment size to  extend each read towards 3' end, then pile them up.  It's exactly twice the number of obsolete SHIFTSIZE.  In previous language, each read is moved 5'->3'  direction to middle of fragment by 1/2 d, then  extended to both direction with 1/2 d. This is  equivalent to say each read is extended towards 5'->3'  into a d size fragment. DEFAULT: 200. EXTSIZE and  SHIFT can be combined when necessary. Check SHIFT  option.",
                    "id": "#macs2-callpeak.cwl/extsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fe-cutoff"
                    },
                    "doc": "FECUTOFF  When set, the value will be used to filter out peaks\nwith low fold-enrichment. Note, MACS2 use 1.0 as\npseudocount while calculating fold-enrichment.\nDEFAULT: 1.0\n",
                    "id": "#macs2-callpeak.cwl/fe-cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fix-bimodal"
                    },
                    "doc": "Whether turn on the auto pair model process. If set, when MACS failed to build paired model, it will use the nomodel settings, the --exsize parameter to extend each tags towards 3' direction. Not to use this automate fixation is a default behavior now. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/fix-bimodal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "-f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE}, --format {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE} Format of tag file, \"AUTO\", \"BED\" or \"ELAND\" or \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\" or \"BOWTIE\" or \"BAMPE\". The default AUTO option will let MACS decide which format the file is. Note that MACS can't detect \"BAMPE\" or \"BEDPE\" format with \"AUTO\", and you have to implicitly specify the format for \"BAMPE\" and \"BEDPE\". DEFAULT: \"AUTO\".",
                    "id": "#macs2-callpeak.cwl/format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "Effective genome size. It can be 1.0e+9 or 1000000000,  or shortcuts:'hs' for human (2.7e9), 'mm' for mouse  (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for  fruitfly (1.2e8), Default:hs.",
                    "id": "#macs2-callpeak.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--keep-dup"
                    },
                    "doc": "KEEPDUPLICATES\nIt controls the MACS behavior towards duplicate tags\nat the exact same location -- the same coordination\nand the same strand. The 'auto' option makes MACS\ncalculate the maximum tags at the exact same location\nbased on binomal distribution using 1e-5 as pvalue\ncutoff; and the 'all' option keeps every tags. If an\ninteger is given, at most this number of tags will be\nkept at the same location. The default is to keep one\ntag at the same location. Default: 1\n",
                    "id": "#macs2-callpeak.cwl/keep-dup"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--llocal"
                    },
                    "doc": "LARGELOCAL   The large nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the surround\nbias. If you set this to 0, MACS will skip llocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT:\n10000.\n",
                    "id": "#macs2-callpeak.cwl/llocal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "MFOLD MFOLD, --mfold MFOLD MFOLD\nSelect the regions within MFOLD range of high-\nconfidence enrichment ratio against background to\nbuild model. Fold-enrichment in regions must be lower\nthan upper limit, and higher than the lower limit. Use\nas \"-m 10 30\". DEFAULT:5 50\n",
                    "id": "#macs2-callpeak.cwl/m"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nolambda"
                    },
                    "doc": "If True, MACS will use fixed background lambda as local lambda for every peak region. Normally, MACS calculates a dynamic local lambda to reflect the local bias due to potential chromatin structure. ",
                    "id": "#macs2-callpeak.cwl/nolambda"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nomodel"
                    },
                    "doc": "\t Whether or not to build the shifting model. If True,  MACS will not build model. by default it means  shifting size = 100, try to set extsize to change it.  DEFAULT: False",
                    "id": "#macs2-callpeak.cwl/nomodel"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-p"
                    },
                    "doc": "Pvalue cutoff for peak detection. DEFAULT: not set.  -q, and -p are mutually exclusive. If pvalue cutoff is  set, qvalue will not be calculated and reported as -1  in the final .xls file..",
                    "id": "#macs2-callpeak.cwl/p"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "Minimum FDR (q-value) cutoff for peak detection. DEFAULT: 0.05. -q, and -p are mutually exclusive.",
                    "id": "#macs2-callpeak.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ratio"
                    },
                    "doc": "RATIO         When set, use a custom scaling ratio of ChIP/control\n(e.g. calculated using NCIS) for linear scaling.\nDEFAULT: ingore\n",
                    "id": "#macs2-callpeak.cwl/ratio"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "TSIZE, --tsize TSIZE\nTag size. This will overide the auto detected tag\nsize. DEFAULT: Not set\n",
                    "id": "#macs2-callpeak.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seed"
                    },
                    "doc": "SEED           Set the random seed while down sampling data. Must be\na non-negative integer in order to be effective.\nDEFAULT: not set\n",
                    "id": "#macs2-callpeak.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--shift"
                    },
                    "doc": "(NOT the legacy --shiftsize option!) The arbitrary shift in bp. Use discretion while setting it other than default value. When NOMODEL is set, MACS will use this value to move cutting ends (5') towards 5'->3' direction then apply EXTSIZE to extend them to fragments. When this value is negative, ends will be moved toward 3'->5' direction. Recommended to keep it as default 0 for ChIP-Seq datasets, or -1 * half of EXTSIZE together with EXTSIZE option for detecting enriched cutting loci such as certain DNAseI-Seq datasets. Note, you can't set values other than 0 if format is BAMPE for paired-end data. DEFAULT: 0.",
                    "id": "#macs2-callpeak.cwl/shift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--slocal"
                    },
                    "doc": "SMALLLOCAL   The small nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the bias near\nthe peak summit region. Invalid if there is no control\ndata. If you set this to 0, MACS will skip slocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT: 1000\n",
                    "id": "#macs2-callpeak.cwl/slocal"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--to-large"
                    },
                    "doc": "When set, scale the small sample up to the bigger sample. By default, the bigger dataset will be scaled down towards the smaller dataset, which will lead to smaller p/qvalues and more specific results. Keep in mind that scaling down will bring down background noise more. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/to-large"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trackline"
                    },
                    "doc": "Tells MACS to include trackline with bedGraph files. To include this trackline while displaying bedGraph at UCSC genome browser, can show name and description of the file as well. However my suggestion is to convert bedGraph to bigWig, then show the smaller and faster binary bigWig file at UCSC genome browser, as well as downstream analysis. Require --bdg to be set. Default: Not include trackline. ",
                    "id": "#macs2-callpeak.cwl/trackline"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--treatment"
                    },
                    "doc": "Treatment sample file(s). If multiple files are given as -t A B C, then they will all be read and pooled together. IMPORTANT: the first sample will be used as the outputs basename.",
                    "id": "#macs2-callpeak.cwl/treatment"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "VERBOSE_LEVEL     Set verbose level of runtime message. 0: only show\ncritical message, 1: show additional warning message,\n2: show process information, 3: show debug messages.\nDEFAULT:2\n",
                    "id": "#macs2-callpeak.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_treat_pileup.bdg')"
                    },
                    "doc": "Bedgraph with extended fragment pileup.",
                    "id": "#macs2-callpeak.cwl/output_ext_frag_bdg_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.*Peak')",
                        "outputEval": "$(self[0])"
                    },
                    "doc": "Peak calling output file in narrowPeak|broadPeak format.",
                    "id": "#macs2-callpeak.cwl/output_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_summits.bed')"
                    },
                    "doc": "Peaks summits bedfile.",
                    "id": "#macs2-callpeak.cwl/output_peak_summits_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.xls')"
                    },
                    "doc": "Peaks information/report file.",
                    "id": "#macs2-callpeak.cwl/output_peak_xls_file"
                }
            ],
            "baseCommand": [
                "macs2",
                "callpeak"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, ''))",
                    "prefix": "-n",
                    "position": 1
                }
            ],
            "id": "#macs2-callpeak.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extract mapped reads from BAM file using Samtools flagstat command",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-extract-number-mapped-reads.cwl/input_bam_file"
                },
                {
                    "type": "string",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "doc": "Samtools Flagstat report file",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": [
                "samtools",
                "flagstat"
            ],
            "arguments": [
                {
                    "valueFrom": " | head -n1 | cut -f 1 -d ' '",
                    "position": 10000,
                    "shellQuote": false
                }
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
            "id": "#samtools-extract-number-mapped-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter BAM file to only include reads overlapping with a BED file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-L"
                    },
                    "doc": "Bedfile used to only include reads overlapping this BED FILE",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bedfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')"
                    },
                    "doc": "Filtered aligned BAM file by BED coordinates file",
                    "id": "#samtools-filter-in-bedfile.cwl/filtered_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b",
                "-h"
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')",
            "id": "#samtools-filter-in-bedfile.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Scale BedGraph file by scaling factor computed using the number of uniq. mapped reads (library size)",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#scale-bedgraph.cwl/bedgraph_file"
                },
                {
                    "type": "string",
                    "default": ".norm.bdg",
                    "id": "#scale-bedgraph.cwl/output_suffix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#scale-bedgraph.cwl/read_count_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bedgraph_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.bdg$/, '') + inputs.output_suffix)"
                    },
                    "id": "#scale-bedgraph.cwl/bedgraph_scaled"
                }
            ],
            "baseCommand": "scale-bedgraph-by-lib-uniq-reads.sh",
            "stdout": "$(inputs.bedgraph_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.bdg$/, '') + inputs.output_suffix)",
            "id": "#scale-bedgraph.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "\"Tool:   bedClip - Remove lines from bed file that refer to off-chromosome places.\nusage:\n   bedClip input.bed chrom.sizes output.bed\nchrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\noptions:\n   -verbose=2 - set to get list of lines clipped and why\"\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bed file to be clipped",
                    "id": "#bedClip.cwl/bed_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "\tgenome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedClip.cwl/genome_sizes"
                },
                {
                    "type": "string",
                    "default": ".clip",
                    "id": "#bedClip.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedClip.cwl/bed_file_clipped"
                }
            ],
            "baseCommand": "bedClip",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
                    "position": 3
                }
            ],
            "id": "#bedClip.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:   bedGraphToBigWig v 4 - Convert a bedGraph file to bigWig format.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "\tbed_graph is a four column file in the format: <chrom> <start> <end> <value>\n",
                    "id": "#bedGraphToBigWig.cwl/bed_graph"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "\tgenome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedGraphToBigWig.cwl/genome_sizes"
                },
                {
                    "type": "string",
                    "default": ".bw",
                    "id": "#bedGraphToBigWig.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedGraphToBigWig.cwl/output_bigwig"
                }
            ],
            "baseCommand": "bedGraphToBigWig",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
                    "position": 3
                }
            ],
            "id": "#bedGraphToBigWig.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "bedSort - Sort a .bed file by chrom,chromStart\nusage:\n   bedSort in.bed out.bed\nin.bed and out.bed may be the same.\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bed or bedGraph file to be sorted",
                    "id": "#bedSort.cwl/bed_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")"
                    },
                    "id": "#bedSort.cwl/bed_file_sorted"
                }
            ],
            "baseCommand": "bedSort",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")",
                    "position": 2
                }
            ],
            "id": "#bedSort.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools slop (aka slopBed)\nVersion: v2.25.0\nSummary: Add requested base pairs of \"slop\" to each feature.\n\nUsage:   bedtools slop [OPTIONS] -i <bed/gff/vcf> -g <genome> [-b <int> or (-l and -r)]\n\nOptions: \n\t-b\tIncrease the BED/GFF/VCF entry -b base pairs in each direction.\n\t\t- (Integer) or (Float, e.g. 0.1) if used with -pct.\n\n\t-l\tThe number of base pairs to subtract from the start coordinate.\n\t\t- (Integer) or (Float, e.g. 0.1) if used with -pct.\n\n\t-r\tThe number of base pairs to add to the end coordinate.\n\t\t- (Integer) or (Float, e.g. 0.1) if used with -pct.\n\n\t-s\tDefine -l and -r based on strand.\n\t\tE.g. if used, -l 500 for a negative-stranded feature, \n\t\tit will add 500 bp downstream.  Default = false.\n\n\t-pct\tDefine -l and -r as a fraction of the feature's length.\n\t\tE.g. if used on a 1000bp feature, -l 0.50, \n\t\twill add 500 bp \"upstream\".  Default = false.\n\n\t-header\tPrint the header from the input file prior to results.\n\nNotes: \n\t(1)  Starts will be set to 0 if options would force it below 0.\n\t(2)  Ends will be set to the chromosome length if  requested slop would\n\tforce it above the max chrom length.\n\t(3)  The genome file should tab delimited and structured as follows:\n\n\t<chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\nTips: \n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\"  > hg19.genome",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-b"
                    },
                    "doc": "Increase the BED/GFF/VCF entry -b base pairs in each direction.\n- (Integer) or (Float, e.g. 0.1) if used with -pct.\n",
                    "id": "#bedtools-slop.cwl/b"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-g"
                    },
                    "doc": "<genome>",
                    "id": "#bedtools-slop.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-header"
                    },
                    "doc": "Print the header from the input file prior to results.\n",
                    "id": "#bedtools-slop.cwl/header"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "doc": "<bed/gff/vcf>",
                    "id": "#bedtools-slop.cwl/i"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "The number of base pairs to subtract from the start coordinate.\n- (Integer) or (Float, e.g. 0.1) if used with -pct.\n",
                    "id": "#bedtools-slop.cwl/l"
                },
                {
                    "type": "string",
                    "default": ".slop",
                    "id": "#bedtools-slop.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-pct"
                    },
                    "doc": "Define -l and -r as a fraction of the feature's length.\nE.g. if used on a 1000bp feature, -l 0.50,\nwill add 500 bp \"upstream\".  Default = false.\n",
                    "id": "#bedtools-slop.cwl/pct"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "The number of base pairs to add to the end coordinate.\n- (Integer) or (Float, e.g. 0.1) if used with -pct.\n",
                    "id": "#bedtools-slop.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "Define -l and -r based on strand.\nE.g. if used, -l 500 for a negative-stranded feature,\nit will add 500 bp downstream.  Default = false.\n",
                    "id": "#bedtools-slop.cwl/s"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.i.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedtools-slop.cwl/stdoutfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "slop"
            ],
            "stdout": "$(inputs.i.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
            "id": "#bedtools-slop.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "usage: An example usage is:$ bamCoverage -b reads.bam -o coverage.bw\n\nThis tool takes an alignment of reads or fragments as input (BAM file) and\ngenerates a coverage track (bigWig or bedGraph) as output. The coverage is\ncalculated as the number of reads per bin, where bins are short consecutive\ncounting windows of a defined size. It is possible to extended the length of\nthe reads to better reflect the actual fragment length. *bamCoverage* offers\nnormalization by scaling factor, Reads Per Kilobase per Million mapped reads\n(RPKM), and 1x depth (reads per genome coverage, RPGC).\nRequired arguments:\n  --bam BAM file, -b BAM file\n                        BAM file to process (default: None)\nOutput:\n  --outFileName FILENAME, -o FILENAME\n                        Output file name. (default: None)\n  --outFileFormat {bigwig,bedgraph}, -of {bigwig,bedgraph}\n                        Output file type. Either \"bigwig\" or \"bedgraph\".\n                        (default: bigwig)\nOptional arguments:\n  --help, -h            show this help message and exit\n  --scaleFactor SCALEFACTOR\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the \u2013binSize is set to 20 and the \u2013smoothLength is\n                        set to 60, then, for each bin, the average of the bin\n                        and its left and right neighbors is considered.\n                        Any value smaller than \u2013binSize will be ignored and\n                        no smoothing will be applied. (default: 1.0)\n  --MNase               Determine nucleosome positions from MNase-seq data.\n                        Only 3 nucleotides at the center of each fragment are\n                        counted. The fragment ends are defined by the two mate\n                        reads. Only fragment lengthsbetween 130 - 200 bp are\n                        considered to avoid dinucleosomes or other\n                        artifacts.*NOTE*: Requires paired-end data. A bin size\n                        of 1 is recommended. (default: False)\n  --filterRNAstrand {forward,reverse}\n                        Selects RNA-seq reads (single-end or paired-end) in\n                        the given strand. (default: None)\n  --version             show program's version number and exit\n  --binSize INT bp, -bs INT bp\n                        Size of the bins, in bases, for the output of the\n                        bigwig/bedgraph file. (default: 50)\n  --region CHR:START:END, -r CHR:START:END\n                        Region of the genome to limit the operation to - this\n                        is useful when testing parameters to reduce the\n                        computing time. The format is chr:start:end, for\n                        example --region chr10 or --region\n                        chr10:456700:891000. (default: None)\n  --blackListFileName BED file, -bl BED file\n                        A BED file containing regions that should be excluded\n                        from all analyses. Currently this works by rejecting\n                        genomic chunks that happen to overlap an entry.\n                        Consequently, for BAM files, if a read partially\n                        overlaps a blacklisted region or a fragment spans over\n                        it, then the read/fragment might still be considered.\n                        (default: None)\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors. (default: max/2)\n  --verbose, -v         Set to see processing messages. (default: False)\nRead coverage normalization options:\n  --normalizeTo1x EFFECTIVE GENOME SIZE LENGTH\n                        Report read coverage normalized to 1x sequencing depth\n                        (also known as Reads Per Genomic Content (RPGC)).\n                        Sequencing depth is defined as: (total number of\n                        mapped reads * fragment length) / effective genome\n                        size. The scaling factor used is the inverse of the\n                        sequencing depth computed for the sample to match the\n                        1x coverage. To use this option, the effective genome\n                        size has to be indicated after the option. The\n                        effective genome size is the portion of the genome\n                        that is mappable. Large fractions of the genome are\n                        stretches of NNNN that should be discarded. Also, if\n                        repetitive regions were not included in the mapping of\n                        reads, the effective genome size needs to be adjusted\n                        accordingly. Common values are: mm9: 2,150,570,000;\n                        hg19:2,451,960,000; dm3:121,400,000 and\n                        ce10:93,260,000. See Table 2 of http://www.plosone.org\n                        /article/info:doi/10.1371/journal.pone.0030377 or http\n                        ://www.nature.com/nbt/journal/v27/n1/fig_tab/nbt.1518_\n                        T1.html for several effective genome sizes. (default:\n                        None)\n--ignoreForNormalization IGNOREFORNORMALIZATION [IGNOREFORNORMALIZATION ...]\n                        A list of space-delimited chromosome names containing\n                        those chromosomes that should be excluded for\n                        computing the normalization. This is useful when\n                        considering samples with unequal coverage across\n                        chromosomes, like male samples. An usage examples is\n                        --ignoreForNormalization chrX chrM. (default: None)\n  --skipNonCoveredRegions, --skipNAs\n                        This parameter determines if non-covered regions\n                        (regions without overlapping reads) in a BAM file\n                        should be skipped. The default is to treat those\n                        regions as having a value of zero. The decision to\n                        skip non-covered regions depends on the interpretation\n                        of the data. Non-covered regions may represent, for\n                        example, repetitive regions that should be skipped.\n                        (default: False)\n  --smoothLength INT bp\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the --binSize is set to 20 and the --smoothLength\n                        is set to 60, then, for each bin, the average of the\n                        bin and its left and right neighbors is considered.\n                        Any value smaller than --binSize will be ignored and\n                        no smoothing will be applied. (default: None)\nRead processing options:\n  --extendReads [INT bp], -e [INT bp]\n                        This parameter allows the extension of reads to\n                        fragment size. If set, each read is extended, without\n                        exception. *NOTE*: This feature is generally NOT\n                        recommended for spliced-read data, such as RNA-seq, as\n                        it would extend reads over skipped regions. *Single-\n                        end*: Requires a user specified value for the final\n                        fragment length. Reads that already exceed this\n                        fragment length will not be extended. *Paired-end*:\n                        Reads with mates are always extended to match the\n                        fragment size defined by the two read mates. Unmated\n                        reads, mate reads that map too far apart (>4x fragment\n                        length) or even map to different chromosomes are\n                        treated like single-end reads. The input of a fragment\n                        length value is optional. If no value is specified, it\n                        is estimated from the data (mean of the fragment size\n                        of all mate reads). (default: False)\n  --ignoreDuplicates    If set, reads that have the same orientation and start\n                        position will be considered only once. If reads are\n                        paired, the mate's position also has to coincide to\n                        ignore a read. (default: False)\n  --minMappingQuality INT\n                        If set, only reads that have a mapping quality score\n                        of at least this are considered. (default: None)\n  --centerReads         By adding this option, reads are centered with respect\n                        to the fragment length. For paired-end data, the read\n                        is centered at the fragment length defined by the two\n                        ends of the fragment. For single-end data, the given\n                        fragment length is used. This option is useful to get\n                        a sharper signal around enriched regions. (default:\n                        False)\n  --samFlagInclude INT  Include reads based on the SAM flag. For example, to\n                        get only reads that are the first mate, use a flag of\n                        64. This is useful to count properly paired reads only\n                        once, as otherwise the second mate will be also\n                        considered for the coverage. (default: None)\n  --samFlagExclude INT  Exclude reads based on the SAM flag. For example, to\n                        get only reads that map to the forward strand, use\n                        --samFlagExclude 16, where 16 is the SAM flag for\n                        reads that map to the reverse strand. (default: None)\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/deeptools:3.0.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--MNase"
                    },
                    "doc": "Determine nucleosome positions from MNase-seq data.\nOnly 3 nucleotides at the center of each fragment are\ncounted. The fragment ends are defined by the two mate\nreads. Only fragment lengthsbetween 130 - 200 bp are\nconsidered to avoid dinucleosomes or other\nartifacts.*NOTE*: Requires paired-end data. A bin size\nof 1 is recommended. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/MNase"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "doc": "BAM file to process ",
                    "id": "#deeptools-bamcoverage.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--binSize"
                    },
                    "doc": "INT bp\nSize of the bins, in bases, for the output of the\nbigwig/bedgraph file. (default: 50)\n",
                    "id": "#deeptools-bamcoverage.cwl/binSize"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--blackListFileName"
                    },
                    "doc": "BED file\nA BED file containing regions that should be excluded\nfrom all analyses. Currently this works by rejecting\ngenomic chunks that happen to overlap an entry.\nConsequently, for BAM files, if a read partially\noverlaps a blacklisted region or a fragment spans over\nit, then the read/fragment might still be considered.\n(default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/blackListFileName"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--centerReads"
                    },
                    "doc": "By adding this option, reads are centered with respect\nto the fragment length. For paired-end data, the read\nis centered at the fragment length defined by the two\nends of the fragment. For single-end data, the given\nfragment length is used. This option is useful to get\na sharper signal around enriched regions. (default:\nFalse)\n",
                    "id": "#deeptools-bamcoverage.cwl/centerReads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extendReads"
                    },
                    "doc": "INT bp\nThis parameter allows the extension of reads to\nfragment size. If set, each read is extended, without\nexception. *NOTE*: This feature is generally NOT\nrecommended for spliced-read data, such as RNA-seq, as\nit would extend reads over skipped regions. *Single-\nend*: Requires a user specified value for the final\nfragment length. Reads that already exceed this\nfragment length will not be extended. *Paired-end*:\nReads with mates are always extended to match the\nfragment size defined by the two read mates. Unmated\nreads, mate reads that map too far apart (>4x fragment\nlength) or even map to different chromosomes are\ntreated like single-end reads. The input of a fragment\nlength value is optional. If no value is specified, it\nis estimated from the data (mean of the fragment size\nof all mate reads). (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/extendReads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--filterRNAstrand"
                    },
                    "doc": "{forward,reverse}\nSelects RNA-seq reads (single-end or paired-end) in\nthe given strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/filterRNAstrand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreDuplicates"
                    },
                    "doc": "If set, reads that have the same orientation and start\nposition will be considered only once. If reads are\npaired, the mate's position also has to coincide to\nignore a read. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreDuplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreForNormalization"
                    },
                    "doc": "A list of space-delimited chromosome names containing those chromosomes\nthat should be excluded for computing the normalization. This is useful\nwhen considering samples with unequal coverage across chromosomes, like\nmale samples. An usage examples is \u2013ignoreForNormalization chrX chrM.\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreForNormalization"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--minMappingQuality"
                    },
                    "doc": "INT\nIf set, only reads that have a mapping quality score\nof at least this are considered. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/minMappingQuality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--normalizeUsing"
                    },
                    "doc": "Possible choices: RPKM, CPM, BPM, RPGC\n\nUse one of the entered methods to normalize the number of reads per bin.\nBy default, no normalization is performed. RPKM = Reads Per Kilobase per\nMillion mapped reads; CPM = Counts Per Million mapped reads, same as\nCPM in RNA-seq; BPM = Bins Per Million mapped reads, same as TPM in\nRNA-seq; RPGC = reads per genomic content (1x normalization);\nMapped reads are considered after blacklist filtering (if applied).\nRPKM (per bin) = number of reads per bin / (number of mapped reads (in millions) * bin length (kb)).\nCPM (per bin) = number of reads per bin / number of mapped reads (in millions).\nBPM (per bin) = number of reads per bin / sum of all reads per bin (in millions).\nRPGC (per bin) = number of reads per bin / scaling factor for 1x average coverage.\nThis scaling factor, in turn, is determined from the sequencing depth:\n(total number of mapped reads * fragment length) / effective genome size.\nThe scaling factor used is the inverse of the sequencing depth\ncomputed for the sample to match the 1x coverage.\nThis option requires \u2013effectiveGenomeSize.\nEach read is considered independently, if you want to only count one\nmate from a pair in paired-end data, then use\nthe \u2013samFlagInclude/\u2013samFlagExclude options.\n",
                    "id": "#deeptools-bamcoverage.cwl/normalizeUsing"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "INT\nNumber of processors to use. Type \"max/2\" to use half\nthe maximum number of processors or \"max\" to use all\navailable processors. (default: max/2)\n",
                    "id": "#deeptools-bamcoverage.cwl/numberOfProcessors"
                },
                {
                    "type": "string",
                    "default": "bigwig",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileFormat"
                    },
                    "doc": "{bigwig,bedgraph}, -of {bigwig,bedgraph}\nOutput file type. Either \"bigwig\" or \"bedgraph\".\n(default: bigwig)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileFormat"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FILENAME\nOutput file name. (default: input BAM filename with bigwig [*.bw] or bedgraph [*.bdg] extension.)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Suffix used for output file (input BAM filename + suffix)",
                    "id": "#deeptools-bamcoverage.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region"
                    },
                    "doc": "CHR:START:END\nRegion of the genome to limit the operation to - this\nis useful when testing parameters to reduce the\ncomputing time. The format is chr:start:end, for\nexample --region chr10 or --region\nchr10:456700:891000. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagExclude"
                    },
                    "doc": "INT  \nExclude reads based on the SAM flag. For example, to\nget only reads that map to the forward strand, use\n--samFlagExclude 16, where 16 is the SAM flag for\nreads that map to the reverse strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagExclude"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagInclude"
                    },
                    "doc": "INT  \nInclude reads based on the SAM flag. For example, to\nget only reads that are the first mate, use a flag of\n64. This is useful to count properly paired reads only\nonce, as otherwise the second mate will be also\nconsidered for the coverage. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagInclude"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scaleFactor"
                    },
                    "doc": "The smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the \u2013binSize is set to 20 and the \u2013smoothLength is\nset to 60, then, for each bin, the average of the bin\nand its left and right neighbors is considered.\nAny value smaller than \u2013binSize will be ignored and\nno smoothing will be applied. (default: 1.0)\n",
                    "id": "#deeptools-bamcoverage.cwl/scaleFactor"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--skipNonCoveredRegions"
                    },
                    "doc": "--skipNonCoveredRegions, --skipNAs\nThis parameter determines if non-covered regions\n(regions without overlapping reads) in a BAM file\nshould be skipped. The default is to treat those\nregions as having a value of zero. The decision to\nskip non-covered regions depends on the interpretation\nof the data. Non-covered regions may represent, for\nexample, repetitive regions that should be skipped.\n(default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/skipNonCoveredRegions"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--smoothLength"
                    },
                    "doc": "INT bp\nThe smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the --binSize is set to 20 and the --smoothLength\nis set to 60, then, for each bin, the average of the\nbin and its left and right neighbors is considered.\nAny value smaller than --binSize will be ignored and\nno smoothing will be applied. (default: None)\nRead processing options:\n",
                    "id": "#deeptools-bamcoverage.cwl/smoothLength"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "--verbose         \nSet to see processing messages. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "show program's version number and exit",
                    "id": "#deeptools-bamcoverage.cwl/version"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }"
                    },
                    "id": "#deeptools-bamcoverage.cwl/output_bam_coverage"
                }
            ],
            "baseCommand": "bamCoverage",
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }",
                    "prefix": "--outFileName",
                    "position": 3
                }
            ],
            "id": "#deeptools-bamcoverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts best fragment length from SPP output text file",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-best-frag-length.cwl/input_spp_txt_file"
                }
            ],
            "outputs": [
                {
                    "type": "float",
                    "outputBinding": {
                        "glob": "best_frag_length",
                        "loadContents": true,
                        "outputEval": "$(Number(self[0].contents.replace('\\n', '')))"
                    },
                    "id": "#extract-best-frag-length.cwl/output_best_frag_length"
                }
            ],
            "baseCommand": "extract-best-frag-length.sh",
            "stdout": "best_frag_length",
            "id": "#extract-best-frag-length.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/spp",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-i=",
                        "separate": false
                    },
                    "doc": "<Input_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped) (FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/control_bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-fdr=",
                        "separate": false
                    },
                    "doc": "-fdr=<falseDisoveryRate> , false discovery rate threshold for peak calling",
                    "id": "#spp.cwl/fdr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-filtchr=",
                        "separate": false
                    },
                    "doc": "-filtchr=<chrnamePattern> , Pattern to use to remove tags that map to specific chromosomes e.g. _ will remove all tags that map to chromosomes with _ in their name",
                    "id": "#spp.cwl/filtchr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c=",
                        "separate": false
                    },
                    "doc": "<ChIP_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped)(FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-npeak=",
                        "separate": false
                    },
                    "doc": "-npeak=<numPeaks>, threshold on number of peaks to call",
                    "id": "#spp.cwl/npeak"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p=",
                        "separate": false
                    },
                    "doc": "-p=<nodes> , number of parallel processing nodes, default=0",
                    "id": "#spp.cwl/nthreads"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-rf"
                    },
                    "doc": "overwrite (force remove) output files in case they exist. Default: true",
                    "id": "#spp.cwl/rf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s=",
                        "separate": false
                    },
                    "doc": "-s=<min>:<step>:<max> , strand shifts at which cross-correlation is evaluated, default=-500:5:1500",
                    "id": "#spp.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savd=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\"; return null}"
                    },
                    "doc": "-savd=<rdatafile> OR -savd, save Rdata file",
                    "id": "#spp.cwl/savd"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savn=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\"; return null}"
                    },
                    "doc": "-savn=<narrowpeakfilename> OR -savn NarrowPeak file name (fixed width peaks)",
                    "id": "#spp.cwl/savn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savp=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\"; return null}"
                    },
                    "doc": "save cross-correlation plot",
                    "id": "#spp.cwl/savp"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savr=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\"; return null}"
                    },
                    "doc": "-savr=<regionpeakfilename> OR -savr RegionPeak file name (variable width peaks with regions of enrichment)",
                    "id": "#spp.cwl/savr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-speak=",
                        "separate": false
                    },
                    "doc": "-speak=<strPeak>, user-defined cross-correlation peak strandshift",
                    "id": "#spp.cwl/speak"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-x=",
                        "separate": false
                    },
                    "doc": "-x=<min>:<max>, strand shifts to exclude (This is mainly to avoid region around phantom peak) default=10:(readlen+10)",
                    "id": "#spp.cwl/x"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                    },
                    "doc": "peakshift/phantomPeak results summary file",
                    "id": "#spp.cwl/output_spp_cross_corr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\")"
                    },
                    "doc": "peakshift/phantomPeak results summary plot",
                    "id": "#spp.cwl/output_spp_cross_corr_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\")"
                    },
                    "doc": "narrowPeak output file",
                    "id": "#spp.cwl/output_spp_narrow_peak"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\")"
                    },
                    "doc": "Rdata file from the run_spp.R run",
                    "id": "#spp.cwl/output_spp_rdata"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\")"
                    },
                    "doc": "regionPeak output file",
                    "id": "#spp.cwl/output_spp_region_peak"
                }
            ],
            "baseCommand": "run_spp.R",
            "arguments": [
                {
                    "valueFrom": "$(\"-out=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                },
                {
                    "valueFrom": "$(\"-tmpdir=\"+runtime.tmpdir)",
                    "shellQuote": false
                }
            ],
            "id": "#spp.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts reads in a fastq file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastq-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastq-reads.cwl/input_fastq_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.read_count.txt')"
                    },
                    "id": "#count-fastq-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": "count-fastq-reads.sh",
            "stdout": "$(inputs.input_basename + '.read_count.txt')",
            "id": "#count-fastq-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts lines in a file and returns a suffixed file with that number",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#count-with-output-suffix.cwl/input_file"
                },
                {
                    "type": "string",
                    "default": ".count",
                    "id": "#count-with-output-suffix.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)"
                    },
                    "id": "#count-with-output-suffix.cwl/output_counts"
                }
            ],
            "baseCommand": [
                "wc",
                "-l"
            ],
            "stdin": "$(inputs.input_file.path)",
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)",
            "id": "#count-with-output-suffix.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts the base name of a file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-basename.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "$(inputs.input_file.path.substr(inputs.input_file.path.lastIndexOf('/') + 1, inputs.input_file.path.lastIndexOf('.') - (inputs.input_file.path.lastIndexOf('/') + 1)))"
                    },
                    "id": "#extract-basename.cwl/output_basename"
                }
            ],
            "baseCommand": "echo",
            "id": "#extract-basename.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
